@@ -8,64 +8,45 @@ use SPVM::Data;
 
 use Carp 'croak';
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
-my $SPVM;
-
-sub get_spvm { $SPVM }
-
-sub new {
-  my $class = shift;
-  
-  my $self = {};
-  
-  $self->{package_infos} = [];
-  $self->{include_paths} = [];
-  
-  return bless $self, __PACKAGE__;
-}
+our $COMPILER;
+our $RUNTIME;
+our @PACKAGE_INFOS;
+our @INCLUDE_PATHS;
+our %SUB_SYMTABLE;
+our %TYPE_SYMTABLE;
+our $ENV;
 
 BEGIN {
-  # SPVM
-  my $spvm = SPVM->new;
-  
   # Add moduel include path
-  push @{$spvm->{include_paths}}, @INC;
-  
-  # Save SPVM
-  $SPVM = $spvm;
+  push @INCLUDE_PATHS, @INC;
 }
 
 # Compile SPVM source code just after compile-time of Perl
 CHECK {
-  # SPVM
-  my $spvm = $SPVM;
-  
   # Compile SPVM source code
-  $spvm->compile;
+  compile();
   
   # Build resolved type symbol table
-  $spvm->build_type_symtable;
+  build_type_symtable();
   
   # Build subroutine symbole table
-  $spvm->build_sub_symtable;
+  build_sub_symtable();
   
   # Build SPVM subroutine
-  $spvm->build_spvm_subs;
+  build_spvm_subs();
   
   # Build run-time
-  $spvm->build_runtime;
+  build_runtime();
   
   # Free compiler
-  $spvm->free_compiler;
+  free_compiler();
 }
 
 sub import {
   my ($class, $package_name) = @_;
   
-  # SPVM
-  my $spvm = $SPVM;
-  
   # Add package infomations
   if (defined $package_name) {
     my ($file, $line) = (caller)[1, 2];
@@ -75,20 +56,16 @@ sub import {
       file => $file,
       line => $line
     };
-    push @{$spvm->{package_infos}}, $package_info;
+    push @PACKAGE_INFOS, $package_info;
   }
 }
 
 sub build_spvm_subs {
-  my $spvm = $SPVM;
-  
-  my $sub_symtable = $spvm->{sub_symtable};
-  
-  for my $abs_name (keys %$sub_symtable) {
+  for my $abs_name (keys %SUB_SYMTABLE) {
     
     my $sub;
     $sub .= "sub SPVM::$abs_name {\n";
-    $sub .= "  SPVM::call_sub(\$spvm, \"$abs_name\", \@_);\n";
+    $sub .= "  SPVM::call_sub(\"$abs_name\", \@_);\n";
     $sub .= "}";
     
     # Define SPVM subroutine
@@ -188,6 +165,24 @@ B<Perl module> - SPVM function can be called from Perl itself (Not yet implement
 
 =back;
 
+If you install SPVM, Perl support B<64 bit integer>.
+
+=head2 FAQ
+
+=over 4
+
+=item * B<Why SPVM don't support 32 bit Perl>
+
+In 32 bit Perl, 64 bit integer is not supported. This means that Perl can not express 64 bit integers on source code.
+
+See the following code.
+
+    my $value = 9223372036854775807;
+
+In 32 bit Perl, 64bit integer value is converted to double automatically. The double value can't express long value accurately.
+
+=back
+
 =head1 AUTHOR
 
 Yuki Kimoto E<lt>kimoto.yuki@gmail.com<gt>
